<?php
/**
 * Webkul MarketingCloudMagentoConnector ProductSaveAfterObserver Observer Model
 *
 * @category  Webkul
 * @package   Webkul_MarketingCloudMagentoConnector
 * @author    Webkul
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 *
 */
namespace Webkul\MarketingCloudMagentoConnector\Observer;

use Magento\Framework\Event\Manager;
use Magento\Framework\Event\ObserverInterface;
use Webkul\MarketingCloudMagentoConnector\Helper\Connection;

class ProductSaveAfterObserver implements ObserverInterface
{
    protected $_state;

    public function __construct(
        \Magento\Framework\App\RequestInterface $requestInterface,
        \Magento\Framework\Message\ManagerInterface $messageManager,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Webkul\MarketingCloudMagentoConnector\Helper\Connection $connection,
        \Magento\ConfigurableProduct\Model\Product\Type\Configurable $configurableModel,
        \Magento\Framework\App\State $state
    ) {
        $this->_connection = $connection;
        $this->_scopeConfig = $scopeConfig;
        $this->_messageManager = $messageManager;
        $this->_requestInterface = $requestInterface;
        $this->_configurableModel = $configurableModel;
        $this->_state = $state;
    }

    /**
     * Product Save After event handler
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(\Magento\Framework\Event\Observer $observer)
    {
        $areaCode = $this->_state->getAreaCode();
        $product = $observer->getEvent()->getProduct();
        $proId = $product->getId();
        $mappingObj = 0;
        $autoSync = $this->_scopeConfig->getValue('marketingcloud/general/mc_autosync');
        if ($proId && $autoSync == '1') {
            $sku = $product->getSku();
            if (!$sku) {
                return true;
            }
            $helper = $this->_connection;
            if ($product->getTypeID() != 'configurable') {
                $res = $helper->getAutoSyncProduct($product);
                if($res && $res[0]){
                    $message = "Product Successfully Exported In DataExtension!!!";
                    if ($areaCode!='frontend') {
                        $this->_messageManager->addSuccess(__($message));
                    }
                } else{
                    $respMessage = $res[1];
                    $error = "Error,  >> ".$respMessage;
                    if ($areaCode!='frontend') {
                        $this->_messageManager->addError(__($error));
                    }
                }
            }
        }
    }
}
